<?php
/**
 * Copyright © FiloBlu S.p.A. 2019. All rights reserved.
 */

namespace FiloBlu\Rma\Plugin\Helper;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Sales\Api\OrderRepositoryInterface;
use Psr\Log\LoggerInterface;

class Data
{
    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;
    /**
     * @var OrderRepositoryInterface
     */
    protected $orderRepository;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    const XML_PATH_VALIDITY_DAYS ='sales/rma_validity_settings/validity_days';
    //const XML_PATH_DAYS_AUTO_APPROVAL ='sales/rma_validity_settings/automatic_approval';


    /**
     * Data constructor.
     * @param ScopeConfigInterface $scopeConfig
     * @param OrderRepositoryInterface $orderRepository
     * @param LoggerInterface $logger
     */
    public function __construct(ScopeConfigInterface $scopeConfig,
                                OrderRepositoryInterface $orderRepository,
                                LoggerInterface $logger){
        $this->scopeConfig = $scopeConfig;
        $this->orderRepository = $orderRepository;
        $this->logger = $logger;
    }


    /**
     * Checks whether the item can be returned based on configuration validity_days
     * @param $orderId
     * @return bool
     */
    public function isValid($orderId)
    {
        //error_log(__METHOD__);
        //return true;

        $validity_days = $this->scopeConfig->getValue(
            self::XML_PATH_VALIDITY_DAYS,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );

        try{
            $order = $this->orderRepository->get($orderId);
            $orderDate = $order->getCreatedAt(); //2019-11-06 13:17:01
            $dateTimeCreated = new \DateTime($orderDate);
            $dateTimeValidityEnds = $dateTimeCreated;
            $dateTimeValidityEnds->modify('+'.$validity_days.' day');
            $today = new \DateTime();
            if($today <= $dateTimeValidityEnds){
                return true;
            }else{
                return false;
            }


        }catch (\Throwable $throwable){
            $this->logger->critical($throwable->getMessage());
            return false;
        }catch (\Exception $e){
            $this->logger->critical($e->getMessage());
            return false;
        }



    }

    /**
     * @param \Magento\Rma\Helper\Data $subject
     * @param $result
     * @param $order
     * @param bool $forceCreate
     * @return bool
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function afterCanCreateRma(\Magento\Rma\Helper\Data $subject , $result, $order, $forceCreate = false)
    {
        if($forceCreate == true){
            return $forceCreate;
        }
        if(!$result){
            return $result;
        }else{
            $result = $this->isValid($order);
            return $result;
        }
    }

}
